@@ -6,9 +6,8 @@ import os
 import random
 from glob import glob
 from .extracteur import ExtracteurDeJus
-from playsound import playsound
+from play_sounds import play_file
 from pathlib import Path
-import time
 directory = os.path.dirname(os.path.abspath(__file__))
 
 
@@ -21,10 +20,8 @@ class nectar(ExtracteurDeJus):
 
     def success(self):
         p = Path(random.choice(self.success_files), encoding=None)
-        playsound(str(p), False)
-        time.sleep(1)
+        play_file(p)
 
     def failure(self):
         p = Path(random.choice(self.failure_files), encoding=None)
-        playsound(str(p), False)
-        time.sleep(1)
+        play_file(p)
